aboutsummaryrefslogtreecommitdiffstats
path: root/drivers
diff options
context:
space:
mode:
Diffstat (limited to 'drivers')
-rw-r--r--drivers/gdisp/Nokia6610/gdisp_lld.c6
-rw-r--r--drivers/gdisp/Nokia6610/gdisp_lld_board_example.h2
-rw-r--r--drivers/gdisp/Nokia6610/gdisp_lld_board_olimexsam7ex256.h2
-rw-r--r--drivers/gdisp/Nokia6610/gdisp_lld_config.h4
-rw-r--r--drivers/gdisp/S6D1121/gdisp_lld.c7
-rw-r--r--drivers/gdisp/S6D1121/gdisp_lld_config.h3
-rw-r--r--drivers/gdisp/S6D1121/s6d1121_lld.c.h3
-rw-r--r--drivers/gdisp/SSD1289/gdisp_lld.c4
-rw-r--r--drivers/gdisp/SSD1963/gdisp_lld.c6
-rw-r--r--drivers/gdisp/SSD1963/gdisp_lld_config.h5
-rw-r--r--drivers/gdisp/SSD1963/ssd1963.h10
-rw-r--r--drivers/gdisp/TestStub/gdisp_lld.c4
-rw-r--r--drivers/gdisp/TestStub/gdisp_lld_config.h2
-rw-r--r--drivers/gdisp/VMT/gdisp_lld.c5
-rw-r--r--drivers/gdisp/VMT/gdisp_lld_config.h3
-rw-r--r--drivers/gdisp/VMT/gdisp_lld_driver1.c5
-rw-r--r--drivers/gdisp/VMT/gdisp_lld_driver2.c5
-rw-r--r--drivers/gdisp/Win32/gdisp_lld.c5
-rw-r--r--drivers/gdisp/Win32/gdisp_lld_config.h5
-rw-r--r--drivers/touchpad/ADS7843/readme.txt8
-rw-r--r--drivers/touchpad/ADS7843/touchpad_lld.mk6
-rw-r--r--drivers/touchpad/XPT2046/readme.txt8
-rw-r--r--drivers/touchpad/XPT2046/touchpad_lld.mk6
-rw-r--r--drivers/touchscreen/ADS7843/readme.txt8
-rw-r--r--drivers/touchscreen/ADS7843/touchscreen_lld.c (renamed from drivers/touchpad/XPT2046/touchpad_lld.c)96
-rw-r--r--drivers/touchscreen/ADS7843/touchscreen_lld.mk6
-rw-r--r--drivers/touchscreen/ADS7843/touchscreen_lld_config.h (renamed from drivers/touchpad/ADS7843/touchpad_lld_config.h)21
-rw-r--r--drivers/touchscreen/XPT2046/readme.txt8
-rw-r--r--drivers/touchscreen/XPT2046/touchscreen_lld.c (renamed from drivers/touchpad/ADS7843/touchpad_lld.c)96
-rw-r--r--drivers/touchscreen/XPT2046/touchscreen_lld.mk6
-rw-r--r--drivers/touchscreen/XPT2046/touchscreen_lld_config.h (renamed from drivers/touchpad/XPT2046/touchpad_lld_config.h)21
31 files changed, 192 insertions, 184 deletions
diff --git a/drivers/gdisp/Nokia6610/gdisp_lld.c b/drivers/gdisp/Nokia6610/gdisp_lld.c
index 23b0d1a7..e5a3160b 100644
--- a/drivers/gdisp/Nokia6610/gdisp_lld.c
+++ b/drivers/gdisp/Nokia6610/gdisp_lld.c
@@ -19,7 +19,7 @@
*/
/**
- * @file gdispNokia6610/gdisp_lld.c
+ * @file drivers/gdisp/Nokia6610/gdisp_lld.c
* @brief GDISP Graphics Driver subsystem low level driver source for the Nokia6610 display.
*
* @addtogroup GDISP
@@ -30,7 +30,7 @@
#include "hal.h"
#include "gdisp.h"
-#if GFX_USE_GDISP || defined(__DOXYGEN__)
+#if GFX_USE_GDISP /*|| defined(__DOXYGEN__)*/
/* Include the emulation code for things we don't support */
#include "gdisp_emulation.c"
@@ -448,7 +448,7 @@ void GDISP_LLD(drawpixel)(coord_t x, coord_t y, color_t color) {
#if GDISP_HARDWARE_CONTROL || defined(__DOXYGEN__)
/**
* @brief Driver Control
- * @detail Unsupported control codes are ignored.
+ * @details Unsupported control codes are ignored.
* @note The value parameter should always be typecast to (void *).
* @note There are some predefined and some specific to the low level driver.
* @note GDISP_CONTROL_POWER - Takes a gdisp_powermode_t
diff --git a/drivers/gdisp/Nokia6610/gdisp_lld_board_example.h b/drivers/gdisp/Nokia6610/gdisp_lld_board_example.h
index 2681a235..c76cf83c 100644
--- a/drivers/gdisp/Nokia6610/gdisp_lld_board_example.h
+++ b/drivers/gdisp/Nokia6610/gdisp_lld_board_example.h
@@ -19,7 +19,7 @@
*/
/**
- * @file gdispNokia6610/gdisp_lld_board_example.h
+ * @file drivers/gdisp/Nokia6610/gdisp_lld_board_example.h
* @brief GDISP Graphic Driver subsystem board interface for the Nokia6610 display.
*
* @addtogroup GDISP
diff --git a/drivers/gdisp/Nokia6610/gdisp_lld_board_olimexsam7ex256.h b/drivers/gdisp/Nokia6610/gdisp_lld_board_olimexsam7ex256.h
index 679773ab..6ab59c3e 100644
--- a/drivers/gdisp/Nokia6610/gdisp_lld_board_olimexsam7ex256.h
+++ b/drivers/gdisp/Nokia6610/gdisp_lld_board_olimexsam7ex256.h
@@ -23,7 +23,7 @@
#endif
/**
- * @file gdispNokia6610/gdisp_lld_board_olimexsam7ex256.h
+ * @file drivers/gdisp/Nokia6610/gdisp_lld_board_olimexsam7ex256.h
* @brief GDISP Graphic Driver subsystem board interface for the Olimex SAM7-EX256 board.
*
* @addtogroup GDISP
diff --git a/drivers/gdisp/Nokia6610/gdisp_lld_config.h b/drivers/gdisp/Nokia6610/gdisp_lld_config.h
index 23ae3cde..f751020f 100644
--- a/drivers/gdisp/Nokia6610/gdisp_lld_config.h
+++ b/drivers/gdisp/Nokia6610/gdisp_lld_config.h
@@ -19,7 +19,7 @@
*/
/**
- * @file gdispNokia6610/gdisp_lld_config.h
+ * @file drivers/gdisp/Nokia6610/gdisp_lld_config.h
* @brief GDISP Graphic Driver subsystem low level driver header for the Nokia6610 display.
*
* @addtogroup GDISP
@@ -29,7 +29,7 @@
#ifndef _GDISP_LLD_CONFIG_H
#define _GDISP_LLD_CONFIG_H
-#if GFX_USE_GDISP
+#if GFX_USE_GDISP
/*===========================================================================*/
/* Driver hardware support. */
diff --git a/drivers/gdisp/S6D1121/gdisp_lld.c b/drivers/gdisp/S6D1121/gdisp_lld.c
index e199f58f..5eaa8e73 100644
--- a/drivers/gdisp/S6D1121/gdisp_lld.c
+++ b/drivers/gdisp/S6D1121/gdisp_lld.c
@@ -19,7 +19,7 @@
*/
/**
- * @file gdispS6d1121/gdisp_lld.c
+ * @file drivers/gdisp/S6D1121/gdisp_lld.c
* @brief GDISP Graphics Driver subsystem low level driver source for the S6d1121 display.
*
* @addtogroup GDISP
@@ -30,7 +30,7 @@
#include "hal.h"
#include "gdisp.h"
-#if GFX_USE_GDISP || defined(__DOXYGEN__)
+#if GFX_USE_GDISP /*|| defined(__DOXYGEN__)*/
/* Include the emulation code for things we don't support */
#include "gdisp_emulation.c"
@@ -411,7 +411,7 @@ void GDISP_LLD(drawpixel)(coord_t x, coord_t y, color_t color) {
#if GDISP_HARDWARE_CONTROL || defined(__DOXYGEN__)
/**
* @brief Driver Control
- * @detail Unsupported control codes are ignored.
+ * @details Unsupported control codes are ignored.
* @note The value parameter should always be typecast to (void *).
* @note There are some predefined and some specific to the low level driver.
* @note GDISP_CONTROL_POWER - Takes a gdisp_powermode_t
@@ -501,3 +501,4 @@ void GDISP_LLD(drawpixel)(coord_t x, coord_t y, color_t color) {
#endif /* GFX_USE_GDISP */
/** @} */
+
diff --git a/drivers/gdisp/S6D1121/gdisp_lld_config.h b/drivers/gdisp/S6D1121/gdisp_lld_config.h
index 8135871e..cc1b2907 100644
--- a/drivers/gdisp/S6D1121/gdisp_lld_config.h
+++ b/drivers/gdisp/S6D1121/gdisp_lld_config.h
@@ -19,7 +19,7 @@
*/
/**
- * @file gdispS6d1121/gdisp_lld_config.h
+ * @file drivers/gdisp/S6D1121/gdisp_lld_config.h
* @brief GDISP Graphic Driver subsystem low level driver header for the S6d1121 display.
*
* @addtogroup GDISP
@@ -51,3 +51,4 @@
#endif /* _GDISP_LLD_CONFIG_H */
/** @} */
+
diff --git a/drivers/gdisp/S6D1121/s6d1121_lld.c.h b/drivers/gdisp/S6D1121/s6d1121_lld.c.h
index 9d7223a9..b8f8078b 100644
--- a/drivers/gdisp/S6D1121/s6d1121_lld.c.h
+++ b/drivers/gdisp/S6D1121/s6d1121_lld.c.h
@@ -1,5 +1,5 @@
/*
- ChibiOS/RT - Copyright (C) 2012
+ ChibiOS/GFX - Copyright (C) 2012
Joel Bodenmann aka Tectu <joel@unormal.org>
This file is part of ChibiOS/GFX.
@@ -251,3 +251,4 @@ static void lld_lcdResetViewPort(void) {
}
#endif /* S6D1121_H */
+
diff --git a/drivers/gdisp/SSD1289/gdisp_lld.c b/drivers/gdisp/SSD1289/gdisp_lld.c
index 321923e0..3568a6f1 100644
--- a/drivers/gdisp/SSD1289/gdisp_lld.c
+++ b/drivers/gdisp/SSD1289/gdisp_lld.c
@@ -30,7 +30,7 @@
#include "hal.h"
#include "gdisp.h"
-#if GFX_USE_GDISP || defined(__DOXYGEN__)
+#if GFX_USE_GDISP /*|| defined(__DOXYGEN__)*/
/* Include the emulation code for things we don't support */
#include "gdisp_emulation.c"
@@ -385,7 +385,7 @@ void GDISP_LLD(drawpixel)(coord_t x, coord_t y, color_t color) {
#if (GDISP_NEED_CONTROL && GDISP_HARDWARE_CONTROL) || defined(__DOXYGEN__)
/**
* @brief Driver Control
- * @detail Unsupported control codes are ignored.
+ * @details Unsupported control codes are ignored.
* @note The value parameter should always be typecast to (void *).
* @note There are some predefined and some specific to the low level driver.
* @note GDISP_CONTROL_POWER - Takes a gdisp_powermode_t
diff --git a/drivers/gdisp/SSD1963/gdisp_lld.c b/drivers/gdisp/SSD1963/gdisp_lld.c
index e54e889d..aceeb4a7 100644
--- a/drivers/gdisp/SSD1963/gdisp_lld.c
+++ b/drivers/gdisp/SSD1963/gdisp_lld.c
@@ -19,7 +19,7 @@
*/
/**
- * @file SSD1963/gdisp_lld.c
+ * @file drivers/gdisp/SSD1963/gdisp_lld.c
* @brief GDISP Graphics Driver subsystem low level driver source.
*
* @addtogroup GDISP
@@ -30,7 +30,7 @@
#include "hal.h"
#include "gdisp.h"
-#if GFX_USE_GDISP || defined(__DOXYGEN__)
+#if GFX_USE_GDISP /*|| defined(__DOXYGEN__)*/
/* Include the emulation code for things we don't support */
#include "gdisp_emulation.c"
@@ -511,7 +511,7 @@ void GDISP_LLD(drawpixel)(coord_t x, coord_t y, color_t color) {
#if (GDISP_NEED_CONTROL && GDISP_HARDWARE_CONTROL) || defined(__DOXYGEN__)
/**
* @brief Driver Control
- * @detail Unsupported control codes are ignored.
+ * @details Unsupported control codes are ignored.
* @note The value parameter should always be typecast to (void *).
* @note There are some predefined and some specific to the low level driver.
* @note GDISP_CONTROL_POWER - Takes a gdisp_powermode_t
diff --git a/drivers/gdisp/SSD1963/gdisp_lld_config.h b/drivers/gdisp/SSD1963/gdisp_lld_config.h
index 18d21687..34b4f72b 100644
--- a/drivers/gdisp/SSD1963/gdisp_lld_config.h
+++ b/drivers/gdisp/SSD1963/gdisp_lld_config.h
@@ -19,7 +19,7 @@
*/
/**
- * @file SSD1963/gdisp_lld_config.h
+ * @file drivers/gdisp/SSD1963/gdisp_lld_config.h
* @brief GDISP Graphic Driver subsystem low level driver header.
*
* @addtogroup GDISP
@@ -29,7 +29,7 @@
#ifndef _GDISP_LLD_CONFIG_H
#define _GDISP_LLD_CONFIG_H
-#if GFX_USE_GDISP || defined(__DOXYGEN__)
+#if GFX_USE_GDISP
/*===========================================================================*/
/* Driver hardware support. */
@@ -50,3 +50,4 @@
#endif /* _GDISP_LLD_CONFIG_H */
/** @} */
+
diff --git a/drivers/gdisp/SSD1963/ssd1963.h b/drivers/gdisp/SSD1963/ssd1963.h
index 4635981f..1aa28382 100644
--- a/drivers/gdisp/SSD1963/ssd1963.h
+++ b/drivers/gdisp/SSD1963/ssd1963.h
@@ -18,14 +18,6 @@
along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-/**
- * @file SSD1963/ssd1963.h
- * @brief SSD1963 specific data.
- *
- * @addtogroup GDISP
- * @{
- */
-
#ifndef SSD1963_H
#define SSD1963_H
@@ -138,4 +130,4 @@
#define SSD1963_GET_PIXEL_DATA_INTERFACE 0x00F1
#endif
-/** @} */
+
diff --git a/drivers/gdisp/TestStub/gdisp_lld.c b/drivers/gdisp/TestStub/gdisp_lld.c
index d3b74585..7084737a 100644
--- a/drivers/gdisp/TestStub/gdisp_lld.c
+++ b/drivers/gdisp/TestStub/gdisp_lld.c
@@ -19,7 +19,7 @@
*/
/**
- * @file gdispTestStub/gdisp_lld.c
+ * @file drivers/gdisp/TestStub/gdisp_lld.c
* @brief GDISP Graphics Driver subsystem low level driver source (stub).
*
* @addtogroup GDISP
@@ -30,7 +30,7 @@
#include "hal.h"
#include "gdisp.h"
-#if GFX_USE_GDISP || defined(__DOXYGEN__)
+#if GFX_USE_GDISP /*|| defined(__DOXYGEN__)*/
/* Include the emulation code for things we don't support */
#include "gdisp_emulation.c"
diff --git a/drivers/gdisp/TestStub/gdisp_lld_config.h b/drivers/gdisp/TestStub/gdisp_lld_config.h
index 45c2b6bd..ecf383a9 100644
--- a/drivers/gdisp/TestStub/gdisp_lld_config.h
+++ b/drivers/gdisp/TestStub/gdisp_lld_config.h
@@ -19,7 +19,7 @@
*/
/**
- * @file gdispTestStub/gdisp_lld_config.h
+ * @file drivers/gdisp/TestStub/gdisp_lld_config.h
* @brief GDISP Graphic Driver subsystem low level driver header (stub).
*
* @addtogroup GDISP
diff --git a/drivers/gdisp/VMT/gdisp_lld.c b/drivers/gdisp/VMT/gdisp_lld.c
index f776dedd..6a7d0cfb 100644
--- a/drivers/gdisp/VMT/gdisp_lld.c
+++ b/drivers/gdisp/VMT/gdisp_lld.c
@@ -19,7 +19,7 @@
*/
/**
- * @file gdispVMT/gdisp_lld.c
+ * @file drivers/gdisp/VMT/gdisp_lld.c
* @brief GDISP Graphics Driver subsystem low level driver source for VMT.
*
* @addtogroup GDISP
@@ -30,7 +30,7 @@
#include "hal.h"
#include "gdisp.h"
-#if GFX_USE_GDISP || defined(__DOXYGEN__)
+#if GFX_USE_GDISP /*|| defined(__DOXYGEN__)*/
#define GDISP_LLD_NO_STRUCT
@@ -279,3 +279,4 @@ bool_t gdisp_lld_init_VMT(void) {
#endif /* GFX_USE_GDISP */
/** @} */
+
diff --git a/drivers/gdisp/VMT/gdisp_lld_config.h b/drivers/gdisp/VMT/gdisp_lld_config.h
index 1d44fca3..5f02f1d8 100644
--- a/drivers/gdisp/VMT/gdisp_lld_config.h
+++ b/drivers/gdisp/VMT/gdisp_lld_config.h
@@ -19,7 +19,7 @@
*/
/**
- * @file gdispVMT/gdisp_lld_config.h
+ * @file drivers/gdisp/VMT/gdisp_lld_config.h
* @brief GDISP Graphic Driver subsystem low level driver header template.
*
* @addtogroup GDISP
@@ -68,3 +68,4 @@
#endif /* _GDISP_LLD_CONFIG_H */
/** @} */
+
diff --git a/drivers/gdisp/VMT/gdisp_lld_driver1.c b/drivers/gdisp/VMT/gdisp_lld_driver1.c
index 28fc7992..5bfaaa85 100644
--- a/drivers/gdisp/VMT/gdisp_lld_driver1.c
+++ b/drivers/gdisp/VMT/gdisp_lld_driver1.c
@@ -19,7 +19,7 @@
*/
/**
- * @file gdispVMT/gdisp_lld.c
+ * @file drivers/gdisp/VMT/gdisp_lld_driver1.c
* @brief GDISP Graphics Driver subsystem low level driver source for VMT.
*
* @addtogroup GDISP
@@ -29,7 +29,7 @@
#include "ch.h"
#include "hal.h"
-#if GFX_USE_GDISP || defined(__DOXYGEN__)
+#if GFX_USE_GDISP /*|| defined(__DOXYGEN__)*/
#define CONFIGFILE() <../GDISP_VMT_NAME1()/gdisp_lld_config.h>
#define DRIVERFILE() <../GDISP_VMT_NAME1()/gdisp_lld.c>
@@ -49,3 +49,4 @@
#endif /* GFX_USE_GDISP */
/** @} */
+
diff --git a/drivers/gdisp/VMT/gdisp_lld_driver2.c b/drivers/gdisp/VMT/gdisp_lld_driver2.c
index 9f6bce23..961c43b3 100644
--- a/drivers/gdisp/VMT/gdisp_lld_driver2.c
+++ b/drivers/gdisp/VMT/gdisp_lld_driver2.c
@@ -19,7 +19,7 @@
*/
/**
- * @file gdispVMT/gdisp_lld.c
+ * @file drivers/gdisp/VMT/gdisp_lld_driver2.c
* @brief GDISP Graphics Driver subsystem low level driver source for VMT.
*
* @addtogroup GDISP
@@ -29,7 +29,7 @@
#include "ch.h"
#include "hal.h"
-#if GFX_USE_GDISP || defined(__DOXYGEN__)
+#if GFX_USE_GDISP /*|| defined(__DOXYGEN__)*/
#define CONFIGFILE() <../GDISP_VMT_NAME2()/gdisp_lld_config.h>
#define DRIVERFILE() <../GDISP_VMT_NAME2()/gdisp_lld.c>
@@ -49,3 +49,4 @@
#endif /* GFX_USE_GDISP */
/** @} */
+
diff --git a/drivers/gdisp/Win32/gdisp_lld.c b/drivers/gdisp/Win32/gdisp_lld.c
index efb89e58..523e695d 100644
--- a/drivers/gdisp/Win32/gdisp_lld.c
+++ b/drivers/gdisp/Win32/gdisp_lld.c
@@ -19,7 +19,7 @@
*/
/**
- * @file Win32/gdisp_lld.c
+ * @file drivers/gdisp/Win32/gdisp_lld.c
* @brief GDISP Graphics Driver subsystem low level driver source for Win32.
*
* @addtogroup GDISP
@@ -30,7 +30,7 @@
#include "hal.h"
#include "gdisp.h"
-#if GFX_USE_GDISP || defined(__DOXYGEN__)
+#if GFX_USE_GDISP /*|| defined(__DOXYGEN__)*/
/* Include the emulation code for things we don't support */
#include "gdisp_emulation.c"
@@ -443,3 +443,4 @@ void GDISP_LLD(drawpixel)(coord_t x, coord_t y, color_t color) {
#endif /* GFX_USE_GDISP */
/** @} */
+
diff --git a/drivers/gdisp/Win32/gdisp_lld_config.h b/drivers/gdisp/Win32/gdisp_lld_config.h
index 014ebd7c..e0afa6c3 100644
--- a/drivers/gdisp/Win32/gdisp_lld_config.h
+++ b/drivers/gdisp/Win32/gdisp_lld_config.h
@@ -19,7 +19,7 @@
*/
/**
- * @file Win32/gdisp_lld_config.h
+ * @file drivers/gdisp/Win32/gdisp_lld_config.h
* @brief GDISP Graphic Driver subsystem low level driver header for Win32.
*
* @addtogroup GDISP
@@ -29,7 +29,7 @@
#ifndef _GDISP_LLD_CONFIG_H
#define _GDISP_LLD_CONFIG_H
-#if GFX_USE_GDISP || defined(__DOXYGEN__)
+#if GFX_USE_GDISP /*|| defined(__DOXYGEN__)*/
/*===========================================================================*/
/* Driver hardware support. */
@@ -50,3 +50,4 @@
#endif /* _GDISP_LLD_CONFIG_H */
/** @} */
+
diff --git a/drivers/touchpad/ADS7843/readme.txt b/drivers/touchpad/ADS7843/readme.txt
deleted file mode 100644
index 90eadc32..00000000
--- a/drivers/touchpad/ADS7843/readme.txt
+++ /dev/null
@@ -1,8 +0,0 @@
-To use this driver:
-
-1. Add in your halconf.h:
- a) #define GFX_USE_TOUCHPAD TRUE
-
-2. To your makefile add the following lines:
- include $(GFXLIB)/drivers/touchpadADS7843/touchpad_lld.mk
-
diff --git a/drivers/touchpad/ADS7843/touchpad_lld.mk b/drivers/touchpad/ADS7843/touchpad_lld.mk
deleted file mode 100644
index 6aaa44ee..00000000
--- a/drivers/touchpad/ADS7843/touchpad_lld.mk
+++ /dev/null
@@ -1,6 +0,0 @@
-# List the required driver.
-GFXSRC += $(GFXLIB)/drivers/touchpad/ADS7843/touchpad_lld.c
-
-# Required include directories
-GFXINC += $(GFXLIB)/drivers/touchpad/ADS7843
-
diff --git a/drivers/touchpad/XPT2046/readme.txt b/drivers/touchpad/XPT2046/readme.txt
deleted file mode 100644
index baccebe8..00000000
--- a/drivers/touchpad/XPT2046/readme.txt
+++ /dev/null
@@ -1,8 +0,0 @@
-To use this driver:
-
-1. Add in your halconf.h:
- a) #define GFX_USE_TOUCHPAD TRUE
-
-2. To your makefile add the following lines:
- include $(GFXLIB)/drivers/touchpad/XPT2046/touchpad_lld.mk
-
diff --git a/drivers/touchpad/XPT2046/touchpad_lld.mk b/drivers/touchpad/XPT2046/touchpad_lld.mk
deleted file mode 100644
index 8d662a74..00000000
--- a/drivers/touchpad/XPT2046/touchpad_lld.mk
+++ /dev/null
@@ -1,6 +0,0 @@
-# List the required driver.
-GFXSRC += $(GFXLIB)/drivers/touchpad/XPT2046/touchpad_lld.c
-
-# Required include directories
-GFXINC += $(GFXLIB)/drivers/touchpad/XPT2046
-
diff --git a/drivers/touchscreen/ADS7843/readme.txt b/drivers/touchscreen/ADS7843/readme.txt
new file mode 100644
index 00000000..85f40da5
--- /dev/null
+++ b/drivers/touchscreen/ADS7843/readme.txt
@@ -0,0 +1,8 @@
+To use this driver:
+
+1. Add in your halconf.h:
+ a) #define GFX_USE_TOUCHSCREEN TRUE
+
+2. To your makefile add the following lines:
+ include $(GFXLIB)/drivers/touchscreen/ADS7843/touchscreen_lld.mk
+
diff --git a/drivers/touchscreen/ADS7843/touchscreen_lld.mk b/drivers/touchscreen/ADS7843/touchscreen_lld.mk
new file mode 100644
index 00000000..c58f6647
--- /dev/null
+++ b/drivers/touchscreen/ADS7843/touchscreen_lld.mk
@@ -0,0 +1,6 @@
+# List the required driver.
+GFXSRC += $(GFXLIB)/drivers/touchscreen/ADS7843/touchscreen_lld.c
+
+# Required include directories
+GFXINC += $(GFXLIB)/drivers/touchscreen/ADS7843
+
diff --git a/drivers/touchpad/ADS7843/touchpad_lld_config.h b/drivers/touchscreen/ADS7843/touchscreen_lld_config.h
index fa1e11eb..5769c288 100644
--- a/drivers/touchpad/ADS7843/touchpad_lld_config.h
+++ b/drivers/touchscreen/ADS7843/touchscreen_lld_config.h
@@ -19,26 +19,27 @@
*/
/**
- * @file touchpadADS7843/touchpad_lld_config.h
- * @brief Touchpad Driver subsystem low level driver.
+ * @file drivers/touchscreen/ADS7843/touchscreen_lld_config.h
+ * @brief Touchscreen Driver subsystem low level driver.
*
- * @addtogroup TOUCHPAD
+ * @addtogroup TOUCHSCREEN
* @{
*/
-#ifndef _TOUCHPAD_LLD_CONFIG_H
-#define _TOUCHPAD_LLD_CONFIG_H
+#ifndef TOUCHSCREEN_LLD_CONFIG_H
+#define TOUCHSCREEN_LLD_CONFIG_H
-#if GFX_USE_TOUCHPAD || defined(__DOXYGEN__)
+#if GFX_USE_TOUCHSCREEN /*|| defined(__DOXYGEN__)*/
/*===========================================================================*/
/* Driver hardware support. */
/*===========================================================================*/
-#define TOUCHPAD_HAS_IRQ TRUE
-#define TOUCHPAD_HAS_PRESSURE FALSE
+#define TOUCHSCREEN_HAS_IRQ TRUE
+#define TOUCHSCREEN_HAS_PRESSURE FALSE
-#endif /* GFX_USE_TOUCHPAD */
+#endif /* GFX_USE_TOUCHSCREEN */
-#endif /* _TOUCHPAD_LLD_CONFIG_H */
+#endif /* TOUCHSCREEN_LLD_CONFIG_H */
/** @} */
+
diff --git a/drivers/touchscreen/XPT2046/readme.txt b/drivers/touchscreen/XPT2046/readme.txt
new file mode 100644
index 00000000..a81caf67
--- /dev/null
+++ b/drivers/touchscreen/XPT2046/readme.txt
@@ -0,0 +1,8 @@
+To use this driver:
+
+1. Add in your halconf.h:
+ a) #define GFX_USE_TOUCHSCREEN TRUE
+
+2. To your makefile add the following lines:
+ include $(GFXLIB)/drivers/touchscreen/XPT2046/touchscreen_lld.mk
+
diff --git a/drivers/touchscreen/XPT2046/touchscreen_lld.mk b/drivers/touchscreen/XPT2046/touchscreen_lld.mk
new file mode 100644
index 00000000..39d5caf9
--- /dev/null
+++ b/drivers/touchscreen/XPT2046/touchscreen_lld.mk
@@ -0,0 +1,6 @@
+# List the required driver.
+GFXSRC += $(GFXLIB)/drivers/touchscreen/XPT2046/touchscreen_lld.c
+
+# Required include directories
+GFXINC += $(GFXLIB)/drivers/touchscreen/XPT2046
+
diff --git a/drivers/touchpad/XPT2046/touchpad_lld_config.h b/drivers/touchscreen/XPT2046/touchscreen_lld_config.h
index 801f5d18..1bb8718e 100644
--- a/drivers/touchpad/XPT2046/touchpad_lld_config.h
+++ b/drivers/touchscreen/XPT2046/touchscreen_lld_config.h
@@ -19,26 +19,27 @@
*/
/**
- * @file touchpadXPT2046/touchpad_lld_config.h
- * @brief Touchppad Driver subsystem low level driver.
+ * @file drivers/touchscreen/XPT2046/touchscreen_lld_config.h
+ * @brief Touchscreen Driver subsystem low level driver.
*
- * @addtogroup TOUCHPAD
+ * @addtogroup TOUCHSCREEN
* @{
*/
-#ifndef _TOUCHPAD_LLD_CONFIG_H
-#define _TOUCHPAD_LLD_CONFIG_H
+#ifndef TOUCHSCREEN_LLD_CONFIG_H
+#define TOUCHSCREEN_LLD_CONFIG_H
-#if GFX_USE_TOUCHPAD || defined(__DOXYGEN__)
+#if GFX_USE_TOUCHSCREEN /*|| defined(__DOXYGEN__)*/
/*===========================================================================*/
/* Driver hardware support. */
/*===========================================================================*/
-#define TOUCHPAD_HAS_IRQ TRUE
-#define TOUCHPAD_HAS_PRESSURE TRUE
+#define TOUCHSCREEN_HAS_IRQ TRUE
+#define TOUCHSCREEN_HAS_PRESSURE TRUE
-#endif /* GFX_USE_TOUCHPAD */
+#endif /* GFX_USE_TOUCHSCREEN */
-#endif /* _TOUCHPAD_LLD_CONFIG_H */
+#endif /* TOUCHSCREEN_LLD_CONFIG_H */
/** @} */
+
diff --git a/drivers/touchpad/XPT2046/touchpad_lld.c b/drivers/touchscreen/ADS7843/touchscreen_lld.c
index 4640ca8d..98e25383 100644
--- a/drivers/touchpad/XPT2046/touchpad_lld.c
+++ b/drivers/touchscreen/ADS7843/touchscreen_lld.c
@@ -19,18 +19,18 @@
*/
/**
* @file touchpadXPT2046/touchpad_lld.c
* @brief Touchpad Driver subsystem low level driver source.
*
- * @addtogroup TOUCHPAD
+ * @addtogroup TOUCHSCREEN
* @{
*/
#include "ch.h"
#include "hal.h"
-#include "touchpad.h"
+#include "touchscreen.h"
-#if GFX_USE_TOUCHPAD || defined(__DOXYGEN__)
+#if GFX_USE_TOUCHSCREEN /*|| defined(__DOXYGEN__)*/
/*===========================================================================*/
/* Driver local definitions. */
@@ -44,8 +44,8 @@
/* Driver local variables. */
/*===========================================================================*/
#if !defined(__DOXYGEN__)
- /* Local copy of the current touchpad driver */
- static const TOUCHPADDriver *tpDriver;
+ /* Local copy of the current touchscreen driver */
+ static const TouchscreenDriver *tsDriver;
static uint16_t sampleBuf[7];
#endif
@@ -65,22 +65,24 @@
/* ---- Required Routines ---- */
/**
* @brief Low level Touchpad driver initialization.
*
* @notapi
*/
-void tp_lld_init(const TOUCHPADDriver *tp) {
- tpDriver = tp;
+void ts_lld_init(const TouchscreenDriver *ts) {
+ tsDriver = ts;
- if(tpDriver->direct_init)
- spiStart(tpDriver->spip, tpDriver->spicfg);
+ if(tsDriver->direct_init)
+ spiStart(tsDriver->spip, tsDriver->spicfg);
}
/**
* @brief Reads a conversion from the touchpad
*
* @param[in] cmd The command bits to send to the touchpad
*
* @return The read value 12-bit right-justified
*
@@ -89,14 +91,14 @@ void tp_lld_init(const TOUCHPADDriver *tp) {
*
* @notapi
*/
-uint16_t tp_lld_read_value(uint8_t cmd) {
+uint16_t ts_lld_read_value(uint8_t cmd) {
static uint8_t txbuf[3] = {0};
static uint8_t rxbuf[3] = {0};
uint16_t ret;
txbuf[0] = cmd;
- spiExchange(tpDriver->spip, 3, txbuf, rxbuf);
+ spiExchange(tsDriver->spip, 3, txbuf, rxbuf);
ret = (rxbuf[1] << 5) | (rxbuf[2] >> 3);
@@ -104,18 +106,18 @@ uint16_t tp_lld_read_value(uint8_t cmd) {
}
/**
* @brief 7-point median filtering code for touchpad samples
*
* @note This is an internally used routine only.
*
* @notapi
*/
-static void tp_lld_filter(void) {
+static void ts_lld_filter(void) {
uint16_t temp;
int i,j;
for(i = 0; i < 4; i++) {
- for(j=i; j < 7; j++) {
+ for(j = i; j < 7; j++) {
if(sampleBuf[i] > sampleBuf[j]) {
/* Swap the values */
temp = sampleBuf[i];
@@ -133,37 +135,37 @@ static void tp_lld_filter(void) {
*
* @notapi
*/
-uint16_t tp_lld_read_x(void) {
+uint16_t ts_lld_read_x(void) {
int i;
#if defined(SPI_USE_MUTUAL_EXCLUSION)
- spiAcquireBus(tpDriver->spip);
+ spiAcquireBus(tsDriver->spip);
#endif
- TOUCHPAD_SPI_PROLOGUE();
- palClearPad(tpDriver->spicfg->ssport, tpDriver->spicfg->sspad);
+ TOUCHSCREEN_SPI_PROLOGUE();
+ palClearPad(tsDriver->spicfg->ssport, tsDriver->spicfg->sspad);
/* Discard the first conversion - very noisy and keep the ADC on hereafter
* till we are done with the sampling. Note that PENIRQ is disabled.
*/
- tp_lld_read_value(0xD1);
+ ts_lld_read_value(0xD1);
for(i = 0; i < 7; i++) {
- sampleBuf[i]=tp_lld_read_value(0xD1);
+ sampleBuf[i] = ts_lld_read_value(0xD1);
}
/* Switch on PENIRQ once again - perform a dummy read */
- tp_lld_read_value(0xD0);
+ ts_lld_read_value(0xD0);
- palSetPad(tpDriver->spicfg->ssport, tpDriver->spicfg->sspad);
- TOUCHPAD_SPI_EPILOGUE();
+ palSetPad(tsDriver->spicfg->ssport, tsDriver->spicfg->sspad);
+ TOUCHSCREEN_SPI_EPILOGUE();
#if defined(SPI_USE_MUTUAL_EXCLUSION)
- spiReleaseBus(tpDriver->spip);
+ spiReleaseBus(tsDriver->spip);
#endif
/* Find the median - use selection sort */
- tp_lld_filter();
+ ts_lld_filter();
return sampleBuf[3];
}
@@ -173,43 +175,43 @@ uint16_t tp_lld_read_x(void) {
*
* @notapi
*/
-uint16_t tp_lld_read_y(void) {
+uint16_t ts_lld_read_y(void) {
int i;
#if defined(SPI_USE_MUTUAL_EXCLUSION)
- spiAcquireBus(tpDriver->spip);
+ spiAcquireBus(tsDriver->spip);
#endif
- TOUCHPAD_SPI_PROLOGUE();
- palClearPad(tpDriver->spicfg->ssport, tpDriver->spicfg->sspad);
+ TOUCHSCREEN_SPI_PROLOGUE();
+ palClearPad(tsDriver->spicfg->ssport, tsDriver->spicfg->sspad);
/* Discard the first conversion - very noisy and keep the ADC on hereafter
* till we are done with the sampling. Note that PENIRQ is disabled.
*/
- tp_lld_read_value(0x91);
+ ts_lld_read_value(0x91);
for(i = 0; i < 7; i++) {
- sampleBuf[i] = tp_lld_read_value(0x91);
+ sampleBuf[i] = ts_lld_read_value(0x91);
}
/* Switch on PENIRQ once again - perform a dummy read */
- tp_lld_read_value(0x90);
+ ts_lld_read_value(0x90);
- palSetPad(tpDriver->spicfg->ssport, tpDriver->spicfg->sspad);
- TOUCHPAD_SPI_EPILOGUE();
+ palSetPad(tsDriver->spicfg->ssport, tsDriver->spicfg->sspad);
+ TOUCHSCREEN_SPI_EPILOGUE();
#ifdef SPI_USE_MUTUAL_EXCLUSION
- spiReleaseBus(tpDriver->spip);
+ spiReleaseBus(tsDriver->spip);
#endif
/* Find the median - use selection sort */
- tp_lld_filter();
+ ts_lld_filter();
return sampleBuf[3];
}
/* ---- Optional Routines ---- */
-#if TOUCHPAD_HAS_IRQ || defined(__DOXYGEN__)
+#if TOUCHSCREEN_HAS_IRQ || defined(__DOXYGEN__)
/*
* @brief for checking if touchpad is pressed or not.
*
@@ -217,23 +219,23 @@ uint16_t tp_lld_read_y(void) {
*
* @notapi
*/
- uint8_t tp_lld_irq(void) {
- return (!palReadPad(tpDriver->tpIRQPort, tpDriver->tpIRQPin));
+ uint8_t ts_lld_irq(void) {
+ return (!palReadPad(tsDriver->tsIRQPort, tsDriver->tsIRQPin));
}
#endif
-#if TOUCHPAD_HAS_PRESSURE || defined(__DOXYGEN__)
+#if TOUCHSCREEN_HAS_PRESSURE || defined(__DOXYGEN__)
/*
* @brief Reads out the Z direction / pressure.
*
* @notapi
*/
- uint16_t tp_lld_read_z(void) {
+ uint16_t ts_lld_read_z(void) {
/* ToDo */
return 42;
}
#endif
-#endif /* GFX_USE_TOUCHPAD */
+#endif /* GFX_USE_TOUCHSCREEN */
/** @} */
@@ -19,18 +19,18 @@
*/
/**
- * @file touchpadXPT2046/touchpad_lld.c
- * @brief Touchpad Driver subsystem low level driver source.
+ * @file drivers/touchscreen/ADS7843/touchscreen_lld.c
+ * @brief Touchscreen Driver subsystem low level driver source.
*
@@ -65,22 +65,24 @@
/* ---- Required Routines ---- */
/**
- * @brief Low level Touchpad driver initialization.
+ * @brief Low level touchscreen driver initialization.
+ *
+ * @param[in] ts The touchscreen driver
*
* @notapi
@@ -65,22 +65,24 @@
}
/**
- * @brief Reads a conversion from the touchpad
+ * @brief Reads a conversion from the touchscreen
*
@@ -65,22 +65,24 @@
*
- * @param[in] cmd The command bits to send to the touchpad
+ * @param[in] cmd The command bits to send to the touchscreen
*
* @return The read value 12-bit right-justified
@@ -104,18 +106,18 @@ uint16_t tp_lld_read_value(uint8_t cmd) {
}
/**
- * @brief 7-point median filtering code for touchpad samples
+ * @brief 7-point median filtering code for touchscreen samples
*
* @note This is an internally used routine only.
diff --git a/drivers/touchpad/ADS7843/touchpad_lld.c b/drivers/touchscreen/XPT2046/touchscreen_lld.c
index 4640ca8d..90bf0032 100644
--- a/drivers/touchpad/ADS7843/touchpad_lld.c
+++ b/drivers/touchscreen/XPT2046/touchscreen_lld.c
@@ -19,18 +19,18 @@
*/
/**
* @file touchpadXPT2046/touchpad_lld.c
* @brief Touchpad Driver subsystem low level driver source.
*
- * @addtogroup TOUCHPAD
+ * @addtogroup TOUCHSCREEN
* @{
*/
#include "ch.h"
#include "hal.h"
-#include "touchpad.h"
+#include "touchscreen.h"
-#if GFX_USE_TOUCHPAD || defined(__DOXYGEN__)
+#if GFX_USE_TOUCHSCREEN /*|| defined(__DOXYGEN__)*/
/*===========================================================================*/
/* Driver local definitions. */
@@ -45,7 +45,7 @@
/*===========================================================================*/
#if !defined(__DOXYGEN__)
/* Local copy of the current touchpad driver */
- static const TOUCHPADDriver *tpDriver;
+ static const TouchscreenDriver *tsDriver;
static uint16_t sampleBuf[7];
#endif
@@ -65,22 +65,24 @@
/* ---- Required Routines ---- */
/**
* @brief Low level Touchpad driver initialization.
*
* @notapi
*/
-void tp_lld_init(const TOUCHPADDriver *tp) {
- tpDriver = tp;
+void ts_lld_init(const TouchscreenDriver *ts) {
+ tsDriver = ts;
- if(tpDriver->direct_init)
- spiStart(tpDriver->spip, tpDriver->spicfg);
+ if(tsDriver->direct_init)
+ spiStart(tsDriver->spip, tsDriver->spicfg);
}
/**
* @brief Reads a conversion from the touchpad
*
* @param[in] cmd The command bits to send to the touchpad
*
* @return The read value 12-bit right-justified
*
@@ -89,14 +91,14 @@ void tp_lld_init(const TOUCHPADDriver *tp) {
*
* @notapi
*/
-uint16_t tp_lld_read_value(uint8_t cmd) {
+uint16_t ts_lld_read_value(uint8_t cmd) {
static uint8_t txbuf[3] = {0};
static uint8_t rxbuf[3] = {0};
uint16_t ret;
txbuf[0] = cmd;
- spiExchange(tpDriver->spip, 3, txbuf, rxbuf);
+ spiExchange(tsDriver->spip, 3, txbuf, rxbuf);
ret = (rxbuf[1] << 5) | (rxbuf[2] >> 3);
@@ -104,18 +106,18 @@ uint16_t tp_lld_read_value(uint8_t cmd) {
}
/**
* @brief 7-point median filtering code for touchpad samples
*
* @note This is an internally used routine only.
*
* @notapi
*/
-static void tp_lld_filter(void) {
+static void ts_lld_filter(void) {
uint16_t temp;
int i,j;
for(i = 0; i < 4; i++) {
- for(j=i; j < 7; j++) {
+ for(j = i; j < 7; j++) {
if(sampleBuf[i] > sampleBuf[j]) {
/* Swap the values */
temp = sampleBuf[i];
@@ -133,37 +135,37 @@ static void tp_lld_filter(void) {
*
* @notapi
*/
-uint16_t tp_lld_read_x(void) {
+uint16_t ts_lld_read_x(void) {
int i;
#if defined(SPI_USE_MUTUAL_EXCLUSION)
- spiAcquireBus(tpDriver->spip);
+ spiAcquireBus(tsDriver->spip);
#endif
- TOUCHPAD_SPI_PROLOGUE();
- palClearPad(tpDriver->spicfg->ssport, tpDriver->spicfg->sspad);
+ TOUCHSCREEN_SPI_PROLOGUE();
+ palClearPad(tsDriver->spicfg->ssport, tsDriver->spicfg->sspad);
/* Discard the first conversion - very noisy and keep the ADC on hereafter
* till we are done with the sampling. Note that PENIRQ is disabled.
*/
- tp_lld_read_value(0xD1);
+ ts_lld_read_value(0xD1);
for(i = 0; i < 7; i++) {
- sampleBuf[i]=tp_lld_read_value(0xD1);
+ sampleBuf[i] = ts_lld_read_value(0xD1);
}
/* Switch on PENIRQ once again - perform a dummy read */
- tp_lld_read_value(0xD0);
+ ts_lld_read_value(0xD0);
- palSetPad(tpDriver->spicfg->ssport, tpDriver->spicfg->sspad);
- TOUCHPAD_SPI_EPILOGUE();
+ palSetPad(tsDriver->spicfg->ssport, tsDriver->spicfg->sspad);
+ TOUCHSCREEN_SPI_EPILOGUE();
#if defined(SPI_USE_MUTUAL_EXCLUSION)
- spiReleaseBus(tpDriver->spip);
+ spiReleaseBus(tsDriver->spip);
#endif
/* Find the median - use selection sort */
- tp_lld_filter();
+ ts_lld_filter();
return sampleBuf[3];
}
@@ -173,67 +175,67 @@ uint16_t tp_lld_read_x(void) {
*
* @notapi
*/
-uint16_t tp_lld_read_y(void) {
+uint16_t ts_lld_read_y(void) {
int i;
#if defined(SPI_USE_MUTUAL_EXCLUSION)
- spiAcquireBus(tpDriver->spip);
+ spiAcquireBus(tsDriver->spip);
#endif
- TOUCHPAD_SPI_PROLOGUE();
- palClearPad(tpDriver->spicfg->ssport, tpDriver->spicfg->sspad);
+ TOUCHSCREEN_SPI_PROLOGUE();
+ palClearPad(tsDriver->spicfg->ssport, tsDriver->spicfg->sspad);
/* Discard the first conversion - very noisy and keep the ADC on hereafter
* till we are done with the sampling. Note that PENIRQ is disabled.
*/
- tp_lld_read_value(0x91);
+ ts_lld_read_value(0x91);
for(i = 0; i < 7; i++) {
- sampleBuf[i] = tp_lld_read_value(0x91);
+ sampleBuf[i] = ts_lld_read_value(0x91);
}
/* Switch on PENIRQ once again - perform a dummy read */
- tp_lld_read_value(0x90);
+ ts_lld_read_value(0x90);
- palSetPad(tpDriver->spicfg->ssport, tpDriver->spicfg->sspad);
- TOUCHPAD_SPI_EPILOGUE();
+ palSetPad(tsDriver->spicfg->ssport, tsDriver->spicfg->sspad);
+ TOUCHSCREEN_SPI_EPILOGUE();
#ifdef SPI_USE_MUTUAL_EXCLUSION
- spiReleaseBus(tpDriver->spip);
+ spiReleaseBus(tsDriver->spip);
#endif
/* Find the median - use selection sort */
- tp_lld_filter();
+ ts_lld_filter();
return sampleBuf[3];
}
/* ---- Optional Routines ---- */
-#if TOUCHPAD_HAS_IRQ || defined(__DOXYGEN__)
+#if TOUCHSCREEN_HAS_IRQ || defined(__DOXYGEN__)
/*
* @brief for checking if touchpad is pressed or not.
*
* @return 1 if pressed / 0 if not pressed
*
* @notapi
*/
- uint8_t tp_lld_irq(void) {
- return (!palReadPad(tpDriver->tpIRQPort, tpDriver->tpIRQPin));
+ uint8_t ts_lld_irq(void) {
+ return (!palReadPad(tsDriver->tsIRQPort, tsDriver->tsIRQPin));
}
#endif
-#if TOUCHPAD_HAS_PRESSURE || defined(__DOXYGEN__)
+#if TOUCHSCREEN_HAS_PRESSURE || defined(__DOXYGEN__)
/*
* @brief Reads out the Z direction / pressure.
*
* @notapi
*/
- uint16_t tp_lld_read_z(void) {
+ uint16_t ts_lld_read_z(void) {
/* ToDo */
return 42;
}
#endif
-#endif /* GFX_USE_TOUCHPAD */
+#endif /* GFX_USE_TOUCHSCREEN */
/** @} */
@@ -19,18 +19,18 @@
*/
/**
- * @file touchpadXPT2046/touchpad_lld.c
- * @brief Touchpad Driver subsystem low level driver source.
+ * @file drivers/touchscreen/XPT2046/touchscreen_lld.c
+ * @brief Touchscreen Driver subsystem low level driver source.
*
@@ -65,22 +65,24 @@
/* ---- Required Routines ---- */
/**
- * @brief Low level Touchpad driver initialization.
+ * @brief Low level Touchscreen driver initialization.
+ *
+ * @param[in] ts The touchscreen driver struct
*
* @notapi
@@ -65,22 +65,24 @@
}
/**
- * @brief Reads a conversion from the touchpad
+ * @brief Reads a conversion from the touchscreen
*
@@ -65,22 +65,24 @@
*
- * @param[in] cmd The command bits to send to the touchpad
+ * @param[in] cmd The command bits to send to the touchscreen
*
* @return The read value 12-bit right-justified
@@ -104,18 +106,18 @@ uint16_t tp_lld_read_value(uint8_t cmd) {
}
/**
- * @brief 7-point median filtering code for touchpad samples
+ * @brief 7-point median filtering code for touchscreen samples
*
* @note This is an internally used routine only.
@@ -173,67 +175,67 @@ uint16_t tp_lld_read_x(void) {
/*
- * @brief for checking if touchpad is pressed or not.
+ * @brief for checking if touchscreen is pressed or not.
*
* @return 1 if pressed / 0 if not pressed